@@ -89,15 +89,17 @@ class BaseQCticSimulator(BaseBackend):
               ``AerBackend`` instance in the remote simulation platform.
         """
 
+        is_async = bool(kwargs.pop("async_submit", False))
+
         job_id = str(uuid.uuid4())
         job = QCticJob(self, job_id, qobj, run_params=kwargs)
 
-        if not self.api.loop.is_running():
-            _logger.debug("Synchronous job submit: %s", job_id)
-            job.submit()
-        else:
+        if is_async:
             _logger.debug("Asynchronous job submit: %s", job_id)
             job.submit_task = asyncio.ensure_future(job.submit_async())
+        else:
+            _logger.debug("Synchronous job submit: %s", job_id)
+            job.submit()
 
         return job
 
